@@ -103,7 +103,7 @@ class Topology():
                 elif ftype in ["RESI","PRES"] and fieldup[1] ==  topology['resname'].upper():
                     found = True
                     try:
-                        topology["rescharge"]=round(float(field[2]),3)
+                        topology["rescharge"] = round(float(field[2]),3)
                     except (ValueError,IndexError):
                         raise ValueError('Beware:: Error in detecting residue charge of '+topology['resname']+'.')
     
@@ -113,7 +113,7 @@ class Topology():
                 if ftype == "RING":
                     ring=ring+1
                     #topology['atomsinring'][ring]=field[1:]
-                    topology['atomsinring'][ring]=fieldup[1:]
+                    topology['atomsinring'][ring] = fieldup[1:]
                     continue
                 elif ftype == "GROU":
                     topology['groups'].append([nat,0,0])
@@ -376,7 +376,8 @@ class WriteCharmmTopology():
     
     @staticmethod
     def rtf_version(version):
-        return str(version)
+        text =  str(version)
+        return text
     
     @staticmethod
     def rtf_autogenangdih(drude=True):
@@ -388,7 +389,14 @@ class WriteCharmmTopology():
     
     @staticmethod
     def rtf_comment(comment):
-        return comment
+        text = ""          
+        if comment:
+            comment = split_line(comment)
+            for h in header:
+                text += "! "+ h + "\n"
+        else:
+            text="! Written by: amolkit\n"
+        return text
     
     @staticmethod
     def rtf_resname(resname,charge,charge_penalty=0.0,param_penalty=0.0):
@@ -415,11 +423,6 @@ class WriteCharmmTopology():
                penalty=topology['atompenalty_byId'][name])
         return text
 
-    @staticmethod
-    def rtf_end():
-        text = "END"
-        return text
-
     @staticmethod
     def rtf_bond(bt1,bt2):
         text=f"BOND {bt1}  {bt2}"
@@ -445,6 +448,12 @@ class WriteCharmmTopology():
                 text += f"LONE {value[0]} {value[1]} DIST {value[2][0]:>6.4f} SCAL {value[2][1]:>7.1f}\n" 
         return text
 
+    @staticmethod
+    def rtf_end():
+        text = "END"
+        return text
+
+
 def main():
     parser = argparse.ArgumentParser(description='Converts CHARMM Additve stream file into Drude stream file.')
     parser.add_argument('-r','--resi', type=str,help='Provide residue name/s for which drude str has to be created.',required=True)
